Trait ExplorerTransaction
pub trait ExplorerTransaction<Types>{
// Required methods
fn namespace_id(
&self,
) -> <<Types as NodeType>::BlockHeader as QueryableHeader<Types>>::NamespaceId;
fn payload_size(&self) -> u64;
}Expand description
ExplorerTransaction is a trait that allows the Explorer API to be able to retrieve a namespace id from a transaction. This is necessary for the Explorer API to be able to display the namespace id for a TransactionSummary.
Required Methods
fn namespace_id(
&self,
) -> <<Types as NodeType>::BlockHeader as QueryableHeader<Types>>::NamespaceId
fn namespace_id( &self, ) -> <<Types as NodeType>::BlockHeader as QueryableHeader<Types>>::NamespaceId
namespace_id returns the namespace id of the individual transaction.
fn payload_size(&self) -> u64
fn payload_size(&self) -> u64
payload_size returns the size of the payload of the transaction.